@@ -14,6 +14,7 @@
 #include <Transaction/TransactionModel.h>
 
 #include <KConfigGroup>
+#include <KConfigWatcher>
 #include <KFormat>
 #include <KLocalizedString>
 #include <KSharedConfig>
@@ -27,7 +28,7 @@ public:
         , m_allUpdaters(updaters)
     {
         bool cancelable = false;
-        foreach (auto updater, m_allUpdaters) {
+        for (auto updater : qAsConst(m_allUpdaters)) {
             connect(updater, &AbstractBackendUpdater::progressingChanged, this, &UpdateTransaction::slotProgressingChanged);
             connect(updater, &AbstractBackendUpdater::downloadSpeedChanged, this, &UpdateTransaction::slotDownloadSpeedChanged);
             connect(updater, &AbstractBackendUpdater::progressChanged, this, &UpdateTransaction::slotUpdateProgress);
@@ -50,9 +51,9 @@ public:
 
     void cancel() override
     {
-        QVector<AbstractBackendUpdater *> toCancel = m_updatersWaitingForFeedback.isEmpty() ? m_allUpdaters : m_updatersWaitingForFeedback;
+        const QVector<AbstractBackendUpdater *> toCancel = m_updatersWaitingForFeedback.isEmpty() ? m_allUpdaters : m_updatersWaitingForFeedback;
 
-        foreach (auto updater, toCancel) {
+        for (auto updater : toCancel) {
             updater->cancel();
         }
     }
@@ -65,7 +66,7 @@ public:
     bool isProgressing() const
     {
         bool progressing = false;
-        foreach (AbstractBackendUpdater *upd, m_allUpdaters) {
+        for (AbstractBackendUpdater *upd : qAsConst(m_allUpdaters)) {
             progressing |= upd->isProgressing();
         }
         return progressing;
@@ -83,7 +84,7 @@ public:
     void slotUpdateProgress()
     {
         qreal total = 0;
-        foreach (AbstractBackendUpdater *updater, m_allUpdaters) {
+        for (AbstractBackendUpdater *updater : qAsConst(m_allUpdaters)) {
             total += updater->progress();
         }
         setProgress(total / m_allUpdaters.count());
@@ -92,7 +93,7 @@ public:
     void slotDownloadSpeedChanged()
     {
         quint64 total = 0;
-        foreach (AbstractBackendUpdater *updater, m_allUpdaters) {
+        for (AbstractBackendUpdater *updater : qAsConst(m_allUpdaters)) {
             total += updater->downloadSpeed();
         }
         setDownloadSpeed(total);
@@ -129,7 +130,7 @@ void ResourcesUpdatesModel::init()
 {
     const QVector<AbstractResourcesBackend *> backends = ResourcesModel::global()->backends();
     m_lastIsProgressing = false;
-    foreach (AbstractResourcesBackend *b, backends) {
+    for (AbstractResourcesBackend *b : backends) {
         AbstractBackendUpdater *updater = b->backendUpdater();
         if (updater && !m_updaters.contains(updater)) {
             connect(updater, &AbstractBackendUpdater::statusMessageChanged, this, &ResourcesUpdatesModel::message);
@@ -147,11 +148,21 @@ void ResourcesUpdatesModel::init()
 
     // To enable from command line use:
     // kwriteconfig5 --file discoverrc --group Software --key UseOfflineUpdates true
-    KConfigGroup group(KSharedConfig::openConfig(), "Software");
+    auto sharedConfig = KSharedConfig::openConfig();
+    KConfigGroup group(sharedConfig, "Software");
     m_offlineUpdates = group.readEntry<bool>("UseOfflineUpdates", false);
 
+    KConfigWatcher::Ptr watcher = KConfigWatcher::create(sharedConfig);
+    connect(watcher.data(), &KConfigWatcher::configChanged, [=]() {
+        if (m_offlineUpdates == group.readEntry<bool>("UseOfflineUpdates", false)) {
+            return;
+        }
+        Q_EMIT useUnattendedUpdatesChanged();
+    });
+
     auto tm = TransactionModel::global();
-    foreach (auto t, tm->transactions()) {
+    const auto transactions = tm->transactions();
+    for (auto t : transactions) {
         auto updateTransaction = qobject_cast<UpdateTransaction *>(t);
         if (updateTransaction) {
             setTransaction(updateTransaction);
@@ -179,7 +190,7 @@ void ResourcesUpdatesModel::prepare()
         return;
     }
 
-    foreach (AbstractBackendUpdater *upd, m_updaters) {
+    for (AbstractBackendUpdater *upd : qAsConst(m_updaters)) {
         upd->setOfflineUpdates(m_offlineUpdates);
         upd->prepare();
     }
@@ -201,7 +212,7 @@ void ResourcesUpdatesModel::updateAll()
         m_transaction->setStatus(Transaction::SetupStatus);
         setTransaction(m_transaction);
         TransactionModel::global()->addTransaction(m_transaction);
-        Q_FOREACH (AbstractBackendUpdater *upd, updaters) {
+        for (AbstractBackendUpdater *upd : updaters) {
             QMetaObject::invokeMethod(upd, &AbstractBackendUpdater::start, Qt::QueuedConnection);
         }
 
@@ -223,7 +234,7 @@ bool ResourcesUpdatesModel::isProgressing() const
 QList<AbstractResource *> ResourcesUpdatesModel::toUpdate() const
 {
     QList<AbstractResource *> ret;
-    foreach (AbstractBackendUpdater *upd, m_updaters) {
+    for (AbstractBackendUpdater *upd : qAsConst(m_updaters)) {
         ret += upd->toUpdate();
     }
     return ret;
@@ -232,7 +243,7 @@ QList<AbstractResource *> ResourcesUpdatesModel::toUpdate() const
 void ResourcesUpdatesModel::addResources(const QList<AbstractResource *> &resources)
 {
     QHash<AbstractResourcesBackend *, QList<AbstractResource *>> sortedResources;
-    foreach (AbstractResource *res, resources) {
+    for (AbstractResource *res : resources) {
         sortedResources[res->backend()] += res;
     }
 
@@ -244,7 +255,7 @@ void ResourcesUpdatesModel::addResources(const QList<AbstractResource *> &resour
 void ResourcesUpdatesModel::removeResources(const QList<AbstractResource *> &resources)
 {
     QHash<AbstractResourcesBackend *, QList<AbstractResource *>> sortedResources;
-    foreach (AbstractResource *res, resources) {
+    for (AbstractResource *res : resources) {
         sortedResources[res->backend()] += res;
     }
 
@@ -256,7 +267,7 @@ void ResourcesUpdatesModel::removeResources(const QList<AbstractResource *> &res
 QDateTime ResourcesUpdatesModel::lastUpdate() const
 {
     QDateTime ret;
-    foreach (AbstractBackendUpdater *upd, m_updaters) {
+    for (AbstractBackendUpdater *upd : qAsConst(m_updaters)) {
         QDateTime current = upd->lastUpdate();
         if (!ret.isValid() || (current.isValid() && current > ret)) {
             ret = current;
@@ -302,6 +313,11 @@ bool ResourcesUpdatesModel::needsReboot() const
     return false;
 }
 
+bool ResourcesUpdatesModel::useUnattendedUpdates() const
+{
+    return m_offlineUpdates;
+}
+
 void ResourcesUpdatesModel::setOfflineUpdates(bool offline)
 {
     m_offlineUpdates = offline;
